@@ -8,6 +8,7 @@
                              max(v.obj$tri$y)+
                              0.1*diff(range(v.obj$tri$y))),
                            all=F,
+                           do.points=T,
                            main="Voronoi mosaic",
                            sub=deparse(substitute(v.obj)),
                            ...)
@@ -30,7 +31,7 @@
         plot.window(xlim=xlim,ylim=ylim,"")
       }
 
-    points(v.obj$x,v.obj$y)
+    if(do.points) points(v.obj$x,v.obj$y)
 
     for (i in 1:n)
       {
