@@ -10,12 +10,12 @@
 static integer c__3 = 3;
 
 /* Subroutine */ int voronoi_(ncc, lcc, n, x, y, list, lptr, lend, nt, lccc, 
-	lct, ltri, ier)
+	iccc, lct, ltri, ier)
 integer *ncc, *lcc, *n;
 doublereal *x, *y;
 integer *list, *lptr, *lend, *nt;
 doublereal *lccc;
-integer *lct, *ltri, *ier;
+integer *iccc, *lct, *ltri, *ier;
 {
     /* System generated locals */
     integer i__1;
@@ -55,11 +55,12 @@ CK.*/
 
 /*     ON EXIT: */
 /*     NT   - NUMBER OF TRIANGLES */
-/*     LCCC - LIST OF CIRCUMCIRCLE CENTERS (9 by NT): */
+/*     LCCC - LIST OF CIRCUMCIRCLE CENTERS (3 by NT): */
 /*            ROW 1,2: X, Y COORDINATES */
 /*            ROW 3  : TRIANGLE AREA (-1 = REMOVED TRIANGLE) */
-/*            ROW 4-6: NEIGHBOUR TRIANGLE INDICES */
-/*            ROW 7-9: NODE INDICES OF TRIANGLE */
+/*     ICCC   LIST OF NEIGHBOUR RELATIONS (6 by NT): */
+/*            ROW 1-3: NEIGHBOUR TRIANGLE INDICES */
+/*            ROW 4-6: NODE INDICES OF TRIANGLE */
 
 /*     Modules required by VORONOI:  TRLIST, CIRCUM, QSORT, RMSHNB */
 /*     DETERMINE ALL CIRCUMCIRCLE CENTERS */
@@ -71,7 +72,8 @@ CK.*/
     --y;
     --list;
     --lptr;
-    lccc -= 10;
+    lccc -= 4;
+    iccc -= 7;
     ltri -= 10;
 
     /* Function Body */
@@ -90,15 +92,15 @@ CK.*/
 	y3 = y[ltri[it * 9 + 3]];
 	circum_(&x1, &y1, &x2, &y2, &x3, &y3, &ratio, &xc, &yc, &cr, &sa, &ar)
 		;
-	lccc[it * 9 + 1] = xc;
-	lccc[it * 9 + 2] = yc;
-	lccc[it * 9 + 3] = sa;
-	lccc[it * 9 + 4] = (doublereal) ltri[it * 9 + 4];
-	lccc[it * 9 + 5] = (doublereal) ltri[it * 9 + 5];
-	lccc[it * 9 + 6] = (doublereal) ltri[it * 9 + 6];
-	lccc[it * 9 + 7] = (doublereal) ltri[it * 9 + 1];
-	lccc[it * 9 + 8] = (doublereal) ltri[it * 9 + 2];
-	lccc[it * 9 + 9] = (doublereal) ltri[it * 9 + 3];
+	lccc[it * 3 + 1] = xc;
+	lccc[it * 3 + 2] = yc;
+	lccc[it * 3 + 3] = sa;
+	iccc[it * 6 + 1] = ltri[it * 9 + 4];
+	iccc[it * 6 + 2] = ltri[it * 9 + 5];
+	iccc[it * 6 + 3] = ltri[it * 9 + 6];
+	iccc[it * 6 + 4] = ltri[it * 9 + 1];
+	iccc[it * 6 + 5] = ltri[it * 9 + 2];
+	iccc[it * 6 + 6] = ltri[it * 9 + 3];
 /* L10: */
     }
 /*    REMOVE TRIANGLES WITH AREA 0 FROM THE BORDER, UPDATE NEIGBOUR RELATI
@@ -113,15 +115,15 @@ L*/
 L11:
     i__1 = ntri;
     for (it = 1; it <= i__1; ++it) {
-	if (lccc[it * 9 + 3] == 0. && (lccc[it * 9 + 4] == 0. || lccc[it * 9 
-		+ 5] == 0. || lccc[it * 9 + 6] == 0.)) {
+	if (lccc[it * 3 + 3] == 0. && (iccc[it * 6 + 1] == 0 || iccc[it * 6 + 
+		2] == 0 || iccc[it * 6 + 3] == 0)) {
 /*     WE HAVE A 0-TRIANGLE AT THE BORDER */
-	    xp[0] = x[(integer) lccc[it * 9 + 7]];
-	    xp[1] = x[(integer) lccc[it * 9 + 8]];
-	    xp[2] = x[(integer) lccc[it * 9 + 9]];
-	    yp[0] = y[(integer) lccc[it * 9 + 7]];
-	    yp[1] = y[(integer) lccc[it * 9 + 8]];
-	    yp[2] = y[(integer) lccc[it * 9 + 9]];
+	    xp[0] = x[iccc[it * 6 + 4]];
+	    xp[1] = x[iccc[it * 6 + 5]];
+	    xp[2] = x[iccc[it * 6 + 6]];
+	    yp[0] = y[iccc[it * 6 + 4]];
+	    yp[1] = y[iccc[it * 6 + 5]];
+	    yp[2] = y[iccc[it * 6 + 6]];
 	    qsort_(&c__3, xp, ip);
 /*     CHECK IF ALL X AND/OR Y COORDINATES COINCIDE */
 	    if (xp[ip[0] - 1] == xp[ip[2] - 1]) {
@@ -137,22 +139,22 @@ EA 0 */
 			    ip[2] - 1]) {
 /*     TWO POINTS COINCIDE */
 			if (yp[ip[0] - 1] == yp[ip[1] - 1]) {
-			    it1 = (integer) lccc[ip[0] + 3 + it * 9];
-			    it2 = (integer) lccc[ip[1] + 3 + it * 9];
-			    rmshnb_(&it, &it1, &it2, &lccc[10]);
+			    it1 = iccc[ip[0] + it * 6];
+			    it2 = iccc[ip[1] + it * 6];
+			    rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
 			} else {
-			    it1 = (integer) lccc[ip[1] + 3 + it * 9];
-			    it2 = (integer) lccc[ip[2] + 3 + it * 9];
-			    rmshnb_(&it, &it1, &it2, &lccc[10]);
+			    it1 = iccc[ip[1] + it * 6];
+			    it2 = iccc[ip[2] + it * 6];
+			    rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
 			}
 		    } else {
 /*     ALL POINTS DIFFERENT */
-			it1 = (integer) lccc[ip[0] + 3 + it * 9];
-			it2 = (integer) lccc[ip[1] + 3 + it * 9];
-			rmshnb_(&it, &it1, &it2, &lccc[10]);
-			it1 = (integer) lccc[ip[2] + 3 + it * 9];
-			it2 = (integer) lccc[ip[1] + 3 + it * 9];
-			rmshnb_(&it, &it1, &it2, &lccc[10]);
+			it1 = iccc[ip[0] + it * 6];
+			it2 = iccc[ip[1] + it * 6];
+			rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
+			it1 = iccc[ip[2] + it * 6];
+			it2 = iccc[ip[1] + it * 6];
+			rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
 		    }
 		}
 	    } else {
@@ -160,22 +162,22 @@ EA 0 */
 			2] - 1]) {
 /*     TWO POINTS COINCIDE */
 		    if (xp[ip[0] - 1] == xp[ip[1] - 1]) {
-			it1 = (integer) lccc[ip[0] + 3 + it * 9];
-			it2 = (integer) lccc[ip[1] + 3 + it * 9];
-			rmshnb_(&it, &it1, &it2, &lccc[10]);
+			it1 = iccc[ip[0] + it * 6];
+			it2 = iccc[ip[1] + it * 6];
+			rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
 		    } else {
-			it1 = (integer) lccc[ip[1] + 3 + it * 9];
-			it2 = (integer) lccc[ip[2] + 3 + it * 9];
-			rmshnb_(&it, &it1, &it2, &lccc[10]);
+			it1 = iccc[ip[1] + it * 6];
+			it2 = iccc[ip[2] + it * 6];
+			rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
 		    }
 		} else {
 /*     ALL POINTS DIFFERENT */
-		    it1 = (integer) lccc[ip[0] + 3 + it * 9];
-		    it2 = (integer) lccc[ip[1] + 3 + it * 9];
-		    rmshnb_(&it, &it1, &it2, &lccc[10]);
-		    it1 = (integer) lccc[ip[1] + 3 + it * 9];
-		    it2 = (integer) lccc[ip[2] + 3 + it * 9];
-		    rmshnb_(&it, &it1, &it2, &lccc[10]);
+		    it1 = iccc[ip[0] + it * 6];
+		    it2 = iccc[ip[1] + it * 6];
+		    rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
+		    it1 = iccc[ip[1] + it * 6];
+		    it2 = iccc[ip[2] + it * 6];
+		    rmshnb_(&it, &it1, &it2, &lccc[4], &iccc[7]);
 		}
 	    }
 	}
@@ -185,8 +187,8 @@ EA 0 */
 /*     OARE LEFT ON THE BORDER. */
     i__1 = ntri;
     for (it = 1; it <= i__1; ++it) {
-	if (lccc[it * 9 + 3] == 0. && (lccc[it * 9 + 4] == 0. || lccc[it * 9 
-		+ 5] == 0. || lccc[it * 9 + 6] == 0.)) {
+	if (lccc[it * 3 + 3] == 0. && (iccc[it * 6 + 1] == 0 || iccc[it * 6 + 
+		2] == 0 || iccc[it * 6 + 3] == 0)) {
 	    goto L11;
 	}
 /* L30: */
@@ -194,9 +196,10 @@ EA 0 */
     return 0;
 } /* voronoi_ */
 
-/* Subroutine */ int rmshnb_(i0, i1, i2, lccc)
+/* Subroutine */ int rmshnb_(i0, i1, i2, lccc, iccc)
 integer *i0, *i1, *i2;
 doublereal *lccc;
+integer *iccc;
 {
     static integer k;
 
@@ -205,24 +208,25 @@ doublereal *lccc;
 */
 /*     AND VICE VERSA.) */
     /* Parameter adjustments */
-    lccc -= 10;
+    iccc -= 7;
+    lccc -= 4;
 
     /* Function Body */
     for (k = 1; k <= 3; ++k) {
 	if (*i1 > 0) {
-	    if (lccc[k + 3 + *i1 * 9] == (doublereal) (*i0)) {
-		lccc[k + 3 + *i1 * 9] = (doublereal) (*i2);
+	    if (iccc[k + *i1 * 6] == *i0) {
+		iccc[k + *i1 * 6] = *i2;
 	    }
 	}
 	if (*i2 > 0) {
-	    if (lccc[k + 3 + *i2 * 9] == (doublereal) (*i0)) {
-		lccc[k + 3 + *i2 * 9] = (doublereal) (*i1);
+	    if (iccc[k + *i2 * 6] == *i0) {
+		iccc[k + *i2 * 6] = *i1;
 	    }
 	}
 /* L1: */
     }
 /*     MARK TRIANGLE I0 AS REMOVED (AREA= -1) */
-    lccc[*i0 * 9 + 3] = -1.;
+    lccc[*i0 * 3 + 3] = -1.;
     return 0;
 } /* rmshnb_ */
 
